#ifndef KEVENTHISTORYDLG_H
#define KEVENTHISTORYDLG_H
/** KWlan
 *
 *  This File is part of KWlan, a network Manager for KDE.
 *  KWlan is distributed under LGPL license.
 *
 *	@author Thomas Michel <tom.michel@arcor.de>
 */

#include "keventhistory.h"


class KEventHistoryDlg : public KEventHistory
{
  Q_OBJECT

public:
  KEventHistoryDlg(QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
  ~KEventHistoryDlg();
  /*$PUBLIC_FUNCTIONS$*/

public slots:
  /*$PUBLIC_SLOTS$*/
  virtual void          addEvent( WpaMsg msg );
  virtual void          addEvents( WpaMsgList msgs );

protected:
  /*$PROTECTED_FUNCTIONS$*/

protected slots:
  /*$PROTECTED_SLOTS$*/
};

#endif


